/**
 *******************************************************************************
 * @file    adc.c
 * @brief   The application functions of ADC_Data_Read demo for the
 *          TOSHIBA 'TMPM366' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "adc.h"

#define DEMO_TITLE "\
*************************\n\r\
 M366 ADC Data Read Demo \n\r\
*************************\n\r"

#define INDEX_MAX 200U
static uint32_t index = 0;
static char displaybuf[32];

/**
  * @brief  Initialize ADC register and variables
  * @param  None
  * @retval None
  */
void ADC_Init(void)
{
    /* Enable ADC clock supply */
    ADC_SetClkSupply(ENABLE);

    /* set ADC clock */
    ADC_SetClk(ADC_CONVERSION_CLK_80, ADC_FC_DIVIDE_LEVEL_8);

    /* select ADC input channel */
    ADC_SetInputChannel(ADC_AN_11);

    /* Enable ADC repeat mode */
    ADC_SetRepeatMode(ENABLE);

    /* Set interrupt mode */
    ADC_SetINTMode(ADC_INT_CONVERSION_8);

    /* Turn VREF on */
    ADC_SetVref(ENABLE);

    /* Wait at least 3us to ensure the voltage is stable */
    Delay(10U);
}

/**
  * @brief  Send ADC Date value Time value to UART.
  * @param  None
  * @retval None
  */
void ADC_Display(void)
{
    ADC_Result result = ADC_GetConvertResult(ADC_REG_00);
    
    /* with output switching or not */
    if (result.Bit.OutputSwitching == 1U) {
        return; /* discard this result */
    }

    if (++index == INDEX_MAX) {
        index = 0U;

        sprintf(displaybuf, "ADC Value: %4d\0", result.Bit.ADResult);

        printf("\033[2J");  /* clear terminal */
        printf(DEMO_TITLE); /* display title */
        printf(displaybuf); /* display ADC Value */
    }
}

void Delay(int time)
{
    volatile int i = 0;

    for (i = 0; i < (time * 800); ++i);
}
